translate.misc.ourdom.Document

Package translate :: Package misc :: Module ourdom :: Class Document |
[hide private]
[frames] | no frames]

# Class Document

source code

Instance Methods | [hide private]
yieldElementsByTagName(self, name) | source code
searchElementsByTagName(self, name, onlysearch) | source code
createElement(self, tagName) | source code
createElementNS(self, namespaceURI, qualifiedName) | source code
Inherited from `xml.dom.minidom.Document`: `__init__`, `appendChild`, `cloneNode`, `createAttribute`, `createAttributeNS`, `createCDATASection`, `createComment`, `createDocumentFragment`, `createProcessingInstruction`, `createTextNode`, `getElementById`, `getElementsByTagName`, `getElementsByTagNameNS`, `importNode`, `isSupported`, `removeChild`, `renameNode`, `unlink`, `writexml` Inherited from `xml.dom.minidom.Document` (private): `_create_entity`, `_create_notation`, `_get_actualEncoding`, `_get_doctype`, `_get_documentElement`, `_get_documentURI`, `_get_elem_info`, `_get_encoding`, `_get_errorHandler`, `_get_standalone`, `_get_strictErrorChecking`, `_get_version` Inherited from `xml.dom.minidom.Node`: `__nonzero__`, `getInterface`, `getUserData`, `hasChildNodes`, `insertBefore`, `isSameNode`, `normalize`, `replaceChild`, `setUserData`, `toprettyxml`, `toxml` Inherited from `xml.dom.minidom.Node` (private): `_call_user_data_handler`, `_get_childNodes`, `_get_firstChild`, `_get_lastChild`, `_get_localName` Inherited from `xml.dom.xmlbuilder.DocumentLS`: `abort`, `load`, `loadXML`, `saveXML` Inherited from `xml.dom.xmlbuilder.DocumentLS` (private): `_get_async`, `_set_async`

Class Variables | [hide private]
| implementation = `DOMImplementation()`
Inherited from `xml.dom.minidom.Document`: `actualEncoding`, `attributes`, `doctype`, `documentURI`, `encoding`, `errorHandler`, `nextSibling`, `nodeName`, `nodeType`, `nodeValue`, `parentNode`, `previousSibling`, `standalone`, `strictErrorChecking`, `version` Inherited from `xml.dom.minidom.Document` (private): `_child_node_types`, `_magic_id_count` Inherited from `xml.dom.minidom.Node`: `namespaceURI`, `ownerDocument`, `prefix` Inherited from `xml.dom.Node`: `ATTRIBUTE_NODE`, `CDATA_SECTION_NODE`, `COMMENT_NODE`, `DOCUMENT_FRAGMENT_NODE`, `DOCUMENT_NODE`, `DOCUMENT_TYPE_NODE`, `ELEMENT_NODE`, `ENTITY_NODE`, `ENTITY_REFERENCE_NODE`, `NOTATION_NODE`, `PROCESSING_INSTRUCTION_NODE`, `TEXT_NODE` Inherited from `xml.dom.xmlbuilder.DocumentLS`: `async`

Properties | [hide private]
Inherited from `xml.dom.minidom.Document`: `documentElement` Inherited from `xml.dom.minidom.Node`: `firstChild`, `lastChild`, `localName`

Method Details | [hide private]

### createElement(self, tagName) | source code
Overrides: xml.dom.minidom.Document.createElement

### createElementNS(self, namespaceURI, qualifiedName) | source code
Overrides: xml.dom.minidom.Document.createElementNS